@@ -1,6 +1,19 @@
 pub mod sql_cell {
     pub(crate) const SCHEMA: &str = include_str!("sql/cell/schema.sql");
-    pub const UPDATE_INTEGRATE_OPS: &str = include_str!("sql/cell/update_integrate_ops.sql");
+    pub const UPDATE_INTEGRATE_DEP_ACTIVITY: &str =
+        include_str!("sql/cell/update_dep_activity.sql");
+    pub const ACTIVITY_INTEGRATED_UPPER_BOUND: &str =
+        include_str!("sql/cell/activity_integrated_upper_bound.sql");
+    pub const ACTIVITY_MISSING_DEP_UPPER_BOUND: &str =
+        include_str!("sql/cell/activity_missing_dep_upper_bound.sql");
+    pub const UPDATE_INTEGRATE_DEP_STORE_ELEMENT: &str =
+        include_str!("sql/cell/update_dep_store_element.sql");
+    pub const UPDATE_INTEGRATE_DEP_STORE_ENTRY: &str =
+        include_str!("sql/cell/update_dep_store_entry.sql");
+    pub const UPDATE_INTEGRATE_DEP_STORE_ENTRY_BASIS: &str =
+        include_str!("sql/cell/update_dep_store_entry_basis.sql");
+    pub const UPDATE_INTEGRATE_DEP_CREATE_LINK: &str =
+        include_str!("sql/cell/update_dep_create_link.sql");
 
     pub const FETCH_OP_HASHES_P1: &str =
         include_str!("sql/cell/fetch_hashes/fetch_op_hashes_p1.sql");
@@ -45,6 +58,8 @@ pub(crate) mod sql_p2p_agent_store {
     pub(crate) const GOSSIP_QUERY: &str = include_str!("sql/p2p_agent_store/gossip_query.sql");
     pub(crate) const QUERY_NEAR_BASIS: &str =
         include_str!("sql/p2p_agent_store/query_near_basis.sql");
+    pub(crate) const EXTRAPOLATED_COVERAGE: &str =
+        include_str!("sql/p2p_agent_store/extrapolated_coverage.sql");
     pub(crate) const PRUNE: &str = include_str!("sql/p2p_agent_store/prune.sql");
 }
 
