@@ -78,6 +78,7 @@ CREATE TABLE IF NOT EXISTS Header (
 );
 CREATE INDEX IF NOT EXISTS Header_type_idx ON Header ( type );
 CREATE INDEX IF NOT EXISTS Header_author ON Header ( author );
+CREATE INDEX IF NOT EXISTS Header_seq_idx ON Header ( seq );
 
 
 -- NB: basis_hash, header_hash, and entry_hash, in general, will have
@@ -136,10 +137,10 @@ CREATE TABLE IF NOT EXISTS DhtOp (
     dependency          BLOB           NULL,
 
 
-    FOREIGN KEY(header_hash) REFERENCES Header(hash)
+    FOREIGN KEY(header_hash) REFERENCES Header(hash) ON DELETE CASCADE
 );
-CREATE INDEX IF NOT EXISTS DhtOp_type_idx ON DhtOp ( type );
-CREATE INDEX IF NOT EXISTS DhtOp_validation_stage_idx ON DhtOp ( validation_stage );
+CREATE INDEX IF NOT EXISTS DhtOp_type_dep_idx ON DhtOp ( type, dependency );
+CREATE INDEX IF NOT EXISTS DhtOp_validation_stage_idx ON DhtOp ( validation_stage, type, dependency );
 CREATE INDEX IF NOT EXISTS DhtOp_validation_status_idx ON DhtOp ( validation_status );
 CREATE INDEX IF NOT EXISTS DhtOp_authored_timestamp_idx ON DhtOp ( authored_timestamp );
 CREATE INDEX IF NOT EXISTS DhtOp_storage_center_loc_idx ON DhtOp ( storage_center_loc );
